@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with the software; see the file COPYING. If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef __GSM_COLOR_BUTTON_H__
@@ -27,7 +27,9 @@
 #include <gtk/gtk.h>
 #include <cairo.h>
 #include <librsvg/rsvg.h>
+#ifndef RSVG_CAIRO_H
 #include <librsvg/rsvg-cairo.h>
+#endif
 
 G_BEGIN_DECLS
 /* The GtkColorSelectionButton widget is a simple color picker in a button.
