@@ -159,7 +159,11 @@ procdialog_create_renice_dialog (ProcData *procdata)
   	GtkWidget *label;
   	GtkWidget *priority_label;
   	GtkWidget *table;
+#if GTK_CHECK_VERSION(3,0,0)
+  	GtkAdjustment *renice_adj;
+#else
   	GtkObject *renice_adj;
+#endif
   	GtkWidget *hscale;
 	GtkWidget *button;
 	GtkWidget *align;
@@ -178,7 +182,9 @@ procdialog_create_renice_dialog (ProcData *procdata)
 				              NULL);
   	renice_dialog = dialog;
 	gtk_window_set_resizable (GTK_WINDOW (renice_dialog), FALSE);
+#if !GTK_CHECK_VERSION(2,22,0)
 	g_object_set (G_OBJECT (renice_dialog), "has-separator", FALSE, NULL);
+#endif
 	gtk_container_set_border_width (GTK_CONTAINER (renice_dialog), 5);
   	
 	button = gtk_button_new ();
@@ -503,7 +509,9 @@ procdialog_create_preferences_dialog (ProcData *procdata)
 	/* any function to set list height by contents/items inside it. */
 	gtk_window_set_default_size (GTK_WINDOW (dialog), 400, 420);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
+#if !GTK_CHECK_VERSION(2,22,0)
 	g_object_set (G_OBJECT (dialog), "has-separator", FALSE, NULL);
+#endif
 	prefs_dialog = dialog;
 	
 	main_vbox = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
