@@ -512,9 +512,9 @@ static void
 get_process_memory_info(ProcInfo *info)
 {
 	glibtop_proc_mem procmem;
-	MatewnckResourceUsage xresources;
+	WnckResourceUsage xresources;
 
-	matewnck_pid_read_resource_usage (gdk_screen_get_display (gdk_screen_get_default ()),
+	wnck_pid_read_resource_usage (gdk_screen_get_display (gdk_screen_get_default ()),
 				      info->pid,
 				      &xresources);
 
